@@ -13,12 +13,12 @@ use lib qw(../lib);
 	use Moose;
 	extends 'Reflex::UdpPeer';
 
-	sub on_socket_datagram {
+	sub on_datagram {
 		my ($self, $args) = @_;
 		my $data = $args->{datagram};
 
 		if ($data =~ /^\s*shutdown\s*$/) {
-			$self->stop_socket_readable();
+			$self->stop();
 			return;
 		}
 
@@ -28,7 +28,7 @@ use lib qw(../lib);
 		);
 	}
 
-	sub on_socket_error {
+	sub on_error {
 		my ($self, $args) = @_;
 		warn "$args->{op} error $args->{errnum}: $args->{errstr}";
 		$self->destruct();
