@@ -8,11 +8,16 @@ use lib qw(../lib);
 
 {
 	package App;
-	use Reflex::Timer;
-	use base qw(Reflex::Timer);
+	use Reflex::Interval;
+	use base qw(Reflex::Interval);
 
-	sub on_timer_tick {
+	sub on_tick {
 		print "tick at ", scalar(localtime), "...\n";
+
+		# Auto-repeat is defined in the callback.
+		# It doesn't work when we override the callback entirely.
+		# TODO - How can this be mitigated?  after() in the role?
+		shift()->repeat();
 	}
 }
 
