@@ -1,6 +1,6 @@
 package Reflex::Role;
 BEGIN {
-  $Reflex::Role::VERSION = '0.081';
+  $Reflex::Role::VERSION = '0.085';
 }
 use Moose::Role;
 use MooseX::Role::Parameterized;
@@ -13,7 +13,7 @@ use Moose::Exporter;
 
 Moose::Exporter->setup_import_methods(
 	with_caller => [ qw(
-		attribute_parameter method_parameter callback_parameter
+		attribute_parameter method_parameter callback_parameter event_parameter
 		method_emit_and_stop method_emit
 	) ],
 	also => 'MooseX::Role::Parameterized',
@@ -118,6 +118,8 @@ sub method_emit {
 # parameter flags to automatically generate those methods.
 BEGIN { *callback_parameter = *method_parameter; }
 
+BEGIN { *event_parameter = *method_parameter; }
+
 1;
 
 __END__
@@ -128,10 +130,12 @@ Reflex::Role - define a Reflex paramaterized role
 
 =head1 VERSION
 
-version 0.081
+version 0.085
 
 =head1 SYNOPSIS
 
+TODO - Changed again;
+
 	package Reflex::Role::Streaming;
 	use Reflex::Role;
 
@@ -152,7 +156,7 @@ version 0.081
 
 		with 'Reflex::Role::Collectible';
 
-		method_emit_and_stop $cb_error => "error";
+		method_emit_and_stop $cb_error => $p->ev_error();
 
 		with 'Reflex::Role::Reading' => {
 			handle      => $h,
