@@ -1,6 +1,6 @@
 package Reflex::Role::Connecting;
 BEGIN {
-  $Reflex::Role::Connecting::VERSION = '0.081';
+  $Reflex::Role::Connecting::VERSION = '0.085';
 }
 use Reflex::Role;
 
@@ -14,6 +14,9 @@ attribute_parameter port    => "port";
 callback_parameter  cb_success  => qw( on socket success );
 callback_parameter  cb_error    => qw( on socket error );
 
+event_parameter     ev_success  => qw( _ socket success );
+event_parameter     ev_error    => qw( _ socket error );
+
 role {
 	my $p = shift;
 
@@ -106,8 +109,8 @@ role {
 		return;
 	};
 
-	method_emit $cb_success => "success";
-	method_emit $cb_error   => "error";
+	method_emit $cb_success => $p->ev_success();
+	method_emit $cb_error   => $p->ev_error();
 
 	with 'Reflex::Role::Writable' => {
 		handle  => $socket,
@@ -124,7 +127,7 @@ Reflex::Role::Connecting - add non-blocking client connecting to a class
 
 =head1 VERSION
 
-version 0.081
+version 0.085
 
 =head1 SYNOPSIS
 
@@ -209,8 +212,14 @@ connection handler method.  This handler will be called whenever a
 client connection is successfully connected.
 
 The default method name is "on_${socket}_success", where $socket is
-the name of the socket attribute.  This role defines a default
-callback that emits an "success" event.
+the name of the socket attribute.
+
+The role defines a default "on_${socket}_success" callback that emits
+an event with the callback's parameters.  The default event is the
+C<socket> name followed by "_success", as in "XYZ_success".
+
+The role's C<ev_success> parameter changes the name of the success
+event to be emitted.
 
 All callback methods receive two parameters: $self and an anonymous
 hash containing information specific to the callback.  In
@@ -222,9 +231,12 @@ socket that has just established a connection.
 C<cb_error> names the $self method that will be called whenever
 connect() encounters an error.  By default, this method will be the
 catenation of "on_", the C<socket> name, and "_error".  As in
-on_XYZ_error(), if the socket attribute is named "XYZ".  The role
-defines a default callback that will emit an "error" event with
-cb_error()'s parameters.
+on_XYZ_error(), if the socket attribute is named "XYZ".
+
+The role defines a default callback that will emit an event with
+cb_error()'s parameters.  The default event is the C<socket> name
+followed by "_error".  For example, "XYZ_error".  The role's
+C<ev_error> parameter changes the event to be emitted.
 
 C<cb_error> callbacks receive two parameters, $self and an anonymous
 hashref of named values specific to the callback.  Reflex error
