@@ -1,6 +1,6 @@
 package Reflex::Role::Reading;
 BEGIN {
-  $Reflex::Role::Reading::VERSION = '0.081';
+  $Reflex::Role::Reading::VERSION = '0.085';
 }
 use Reflex::Role;
 
@@ -10,6 +10,9 @@ callback_parameter cb_data    => qw( on handle data );
 callback_parameter cb_error   => qw( on handle error );
 callback_parameter cb_closed  => qw( on handle closed );
 
+event_parameter ev_data   => qw( _ handle data );
+event_parameter ev_closed => qw( _ handle closed );
+
 # Matches Reflex::Role::Readable's default callback.
 # TODO - Any way we can coordinate this so it's obvious in the code
 # but not too verbose?
@@ -34,13 +37,13 @@ role {
 		# Got data.
 		if ($octet_count) {
 			$self->$cb_data({ data => $buffer });
-			return;
+			return $octet_count;
 		}
 
 		# EOF
 		if (defined $octet_count) {
 			$self->$cb_closed({ });
-			return;
+			return $octet_count;
 		}
 
 		# Quelle erreur!
@@ -51,11 +54,20 @@ role {
 				errfun => "sysread",
 			}
 		);
+		return; # Nothing.
 	};
 
 	# Default callbacks that re-emit their parameters.
-	method_emit           $cb_data    => "data";
-	method_emit_and_stop  $cb_closed  => "closed";
+
+	method_emit           $cb_data    => $p->ev_data();
+	method_emit_and_stop  $cb_closed  => $p->ev_closed();
+
+#	my $ev_closed = $p->ev_closed();
+#	method $cb_closed => sub {
+#		my ($self, $args) = @_;
+#		$self->emit(event => $ev_closed, args => $args);
+#		$self->stopped();
+#	};
 };
 
 1;
@@ -68,10 +80,12 @@ Reflex::Role::Reading - add standard sysread() behavior to a class
 
 =head1 VERSION
 
-version 0.081
+version 0.085
 
 =head1 SYNOPSIS
 
+TODO - Changed again.
+
 	package InputStreaming;
 	use Reflex::Role;
 
@@ -88,7 +102,7 @@ version 0.081
 		my $cb_error    = $p->cb_error();
 		my $method_read = "on_${h}_readable";
 
-		method_emit_and_stop $cb_error => "error";
+		method_emit_and_stop $cb_error => $p->ev_error();
 
 		with 'Reflex::Role::Reading' => {
 			handle      => $h,
