@@ -1,6 +1,6 @@
 package Reflex::Timeout;
 BEGIN {
-  $Reflex::Timeout::VERSION = '0.081';
+  $Reflex::Timeout::VERSION = '0.085';
 }
 
 use Moose;
@@ -12,7 +12,7 @@ has auto_start  => ( isa => 'Bool', is => 'ro', default => 1 );
 # TODO - There is a flaw in the design.
 #
 # Reflex::Timeout = cb_timeout => "on_done"
-# Reflex::Role::Timeout = method_emit $cb_timeout => "done"
+# Reflex::Role::Timeout = method_emit $cb_timeout => $p->ev_done()
 #
 # However, the user's on_done => callback() only works because the
 # emitted event is "done".  And this "done" is a constant, which means
@@ -25,6 +25,7 @@ has auto_start  => ( isa => 'Bool', is => 'ro', default => 1 );
 with 'Reflex::Role::Timeout' => {
 	delay         => "delay",
 	cb_timeout    => "on_done",
+	ev_timeout    => "done",
 	auto_start    => "auto_start",
 	method_start  => "start",
 	method_stop   => "stop",
@@ -41,7 +42,7 @@ Reflex::Timeout - A stand-alone single-shot delayed callback
 
 =head1 VERSION
 
-version 0.081
+version 0.085
 
 =head1 SYNOPSIS
 
